<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="ru_RU">
<context>
    <name></name>
    <message>
        <source>Error</source>
        <translation type="obsolete">Ошибка</translation>
    </message>
    <message>
        <source>Arora is already running. Exiting.</source>
        <translation type="obsolete">Arora уже запущена. Выходим.</translation>
    </message>
</context>
<context>
    <name>AboutDialog</name>
    <message>
        <source>About</source>
        <translation>О программе</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Lightweight WebKit-based web browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;DejaVu Sans&apos;; font-size:9pt; font-weight:400; font-style:normal;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2008 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Добавить закладку</translation>
    </message>
    <message>
        <source>Type a name for the bookmark, and choose where to keep it.</source>
        <translation>Введите имя для закладки и выберите, где сохранить её.</translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Новая папка</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Закладки</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Добавить папку</translation>
    </message>
    <message>
        <source>Open in New Tab</source>
        <translation>Открыть в новой вкладке</translation>
    </message>
</context>
<context>
    <name>BookmarksManager</name>
    <message>
        <source>Error when loading bookmarks on line %1, column %2:
%3</source>
        <translation>Ошибка при загрузке закладок на строке %1, столбце %2:
%3</translation>
    </message>
    <message>
        <source>Toolbar Bookmarks</source>
        <translation>Закладки панели инструментов</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Меню</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Открыть файл</translation>
    </message>
    <message>
        <source>XBEL (*.xbel *.xml)</source>
        <translation>XBEL (*.xbel *.xml)</translation>
    </message>
    <message>
        <source>Imported %1</source>
        <translation>Импортировано %1</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Сохранить файл</translation>
    </message>
    <message>
        <source>%1 Bookmarks.xbel</source>
        <translation>%1 Bookmarks.xbel</translation>
    </message>
    <message>
        <source>Export error</source>
        <translation>Ошибка экспорта</translation>
    </message>
    <message>
        <source>error saving bookmarks</source>
        <translation>ошибка сохранения закладок</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>Удалить закладку</translation>
    </message>
    <message>
        <source>Insert Bookmark</source>
        <translation>Добавить закладку</translation>
    </message>
    <message>
        <source>Name Change</source>
        <translation>Изменение имени</translation>
    </message>
    <message>
        <source>Address Change</source>
        <translation>Изменение адреса</translation>
    </message>
</context>
<context>
    <name>BookmarksModel</name>
    <message>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
</context>
<context>
    <name>BookmarksToolBar</name>
    <message>
        <source>Bookmark</source>
        <translation>Закладка</translation>
    </message>
</context>
<context>
    <name>BrowserApplication</name>
    <message>
        <source>There are %1 windows and %2 tabs open
Do you want to quit anyway?</source>
        <translation>Открыто %1 окон и %2 вкладок
Вы всё равно хотите выйти?</translation>
    </message>
    <message>
        <source>Restore failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The saved session will not being restored because last time it was restored Arora crashed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrowserMainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation>&amp;Новое окно</translation>
    </message>
    <message>
        <source>&amp;Open File...</source>
        <translation>&amp;Открыть файл...</translation>
    </message>
    <message>
        <source>Open &amp;Location...</source>
        <translation>Открыть &amp;адрес...</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>&amp;Сохранить как...</translation>
    </message>
    <message>
        <source>&amp;Import Bookmarks...</source>
        <translation>&amp;Импортировать закладки...</translation>
    </message>
    <message>
        <source>&amp;Export Bookmarks...</source>
        <translation>&amp;Экспортировать закладки...</translation>
    </message>
    <message>
        <source>P&amp;rint Preview...</source>
        <translation>&amp;Предпросмотр...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Пе&amp;чать...</translation>
    </message>
    <message>
        <source>Private &amp;Browsing...</source>
        <translation>Режим &amp;конфиденциальности...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>В&amp;ыход...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Правка</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Отменить</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Повторить</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>&amp;Вырезать</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Копировать</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>В&amp;ставить</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Найти</translation>
    </message>
    <message>
        <source>&amp;Find Next</source>
        <translation type="obsolete">Найти &amp;далее</translation>
    </message>
    <message>
        <source>&amp;Find Previous</source>
        <translation type="obsolete">Найти пред&amp;ыдущее</translation>
    </message>
    <message>
        <source>&amp;Preferences</source>
        <translation type="obsolete">&amp;Параметры</translation>
    </message>
    <message>
        <source>Ctrl+,</source>
        <translation>Ctrl+,</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Вид</translation>
    </message>
    <message>
        <source>Shift+Ctrl+B</source>
        <translation>Shift+Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Ctrl+/</source>
        <translation>Ctrl+/</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Остановить</translation>
    </message>
    <message>
        <source>Reload Page</source>
        <translation type="obsolete">Обновить страницу</translation>
    </message>
    <message>
        <source>&amp;Make Text Bigger</source>
        <translation type="obsolete">У&amp;величить</translation>
    </message>
    <message>
        <source>&amp;Make Text Normal</source>
        <translation type="obsolete">&amp;Исходный размер</translation>
    </message>
    <message>
        <source>&amp;Make Text Smaller</source>
        <translation type="obsolete">У&amp;меньшить</translation>
    </message>
    <message>
        <source>Page S&amp;ource</source>
        <translation>Исходный &amp;код страницы</translation>
    </message>
    <message>
        <source>Ctrl+Alt+U</source>
        <translation>Ctrl+Alt+U</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Во весь &amp;экран</translation>
    </message>
    <message>
        <source>Hi&amp;story</source>
        <translation>&amp;Журнал</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Вперёд</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Домашняя страница</translation>
    </message>
    <message>
        <source>Restore Last Session</source>
        <translation>Восстанавливать предыдущий сеанс</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Закладки</translation>
    </message>
    <message>
        <source>Manage Bookmarks...</source>
        <translation>Управление закладками...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Добавить закладку...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Окно</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Инструменты</translation>
    </message>
    <message>
        <source>Web &amp;Search</source>
        <translation>&amp;Поиск в Интернете</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <comment>Web Search</comment>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Enable Web &amp;Inspector</source>
        <translation>Включить Web &amp;Inspector</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>О &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;Arora</source>
        <translation>О программе &amp;Arora</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>навигация</translation>
    </message>
    <message>
        <source>Show Status Bar</source>
        <translation>Показать строку состояния</translation>
    </message>
    <message>
        <source>Hide Status Bar</source>
        <translation>Скрыть строку состояния</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation>Показать панель инструментов</translation>
    </message>
    <message>
        <source>Hide Toolbar</source>
        <translation>Скрыть панель инструментов</translation>
    </message>
    <message>
        <source>Show Bookmarks bar</source>
        <translation type="obsolete">Показать панель закладок</translation>
    </message>
    <message>
        <source>Hide Bookmarks bar</source>
        <translation type="obsolete">Скрыть панель закладок</translation>
    </message>
    <message>
        <source>Arora</source>
        <translation>Arora</translation>
    </message>
    <message>
        <source>%1 - Arora</source>
        <comment>Page title and Browser name</comment>
        <translation>%1 - Arora</translation>
    </message>
    <message>
        <source>About</source>
        <translation type="obsolete">О программе</translation>
    </message>
    <message>
        <source>Open Web Resource</source>
        <translation>Открыть веб-ресурс</translation>
    </message>
    <message>
        <source>Web Resources (*.html *.htm *.svg *.png *.gif *.svgz);;All files (*.*)</source>
        <translation>Веб-ресурсы (*.html *.htm *.svg *.png *.gif *.svgz);;Все файлы (*.*)</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>Печать документа</translation>
    </message>
    <message>
        <source>Are you sure you want to turn on private browsing?</source>
        <translation>Вы уверены, что хотите включить режим конфиденциальности?</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing in turned on, webpages are not added to the history, items are automatically removed from the Downloads window, new cookies are not stored, current cookies can&apos;t be accessed, site icons wont be stored, session wont be saved,  and searches are not addded to the pop-up menu in the Google search box.  Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;В режиме конфиденциальности посещённые веб-страницы не добавляются в журнал, файлы автоматически удаляются из окна загрузок, новые cookies are не сохраняются, текущие cookies недоступны, значки сайтов и сеансы не сохраняются, и поисковые запросы не добавляются в поле поиска Google. Пока вы не закроете окно, вы всё ещё можете нажимать кнопки Назад и Вперёд для возврата к уже посещённым страницам.</translation>
    </message>
    <message>
        <source>Are you sure you want to close the window?  There are %1 tabs open</source>
        <translation>Вы уверены, что хотите закрыть окно? Открыты %1 вкладок</translation>
    </message>
    <message>
        <source>Page Source of %1</source>
        <translation>Исходный код страницы %1</translation>
    </message>
    <message>
        <source>Web Inspector</source>
        <translation>Web Inspector</translation>
    </message>
    <message>
        <source>The web inspector will only work correctly for pages that were loaded after enabling.
Do you want to reload all pages?</source>
        <translation>Web Inspector будет правильно работать только для страниц, добавленных после его включения.
Желаете ли вы обновить все страницы?</translation>
    </message>
    <message>
        <source>Stop loading the current page</source>
        <translation>Остановить загрузку текущей страницы</translation>
    </message>
    <message>
        <source>Reload the current page</source>
        <translation>Перезагрузить текущую страницу</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Загрузки</translation>
    </message>
    <message>
        <source>Alt+Ctrl+L</source>
        <comment>Download Manager</comment>
        <translation>Alt+Ctrl+L</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not addded to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttonsto return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;В режиме конфиденциальности отключаются некоторые действия, связанные с вашей анонимностью:&lt;ul&gt;&lt;li&gt; Веб-страницы не добавляются в журнал.&lt;/li&gt;&lt;li&gt; Файлы автоматически удаляются из окна загрузок.&lt;/li&gt;&lt;li&gt; Новые cookies не сохраняются, текущие cookies недоступны.&lt;/li&gt;&lt;li&gt; Значки сайтов и сеансы не сохраняются.&lt;/li&gt;&lt;li&gt; Поисковые запросы не добавляются в поле поиска.&lt;/li&gt;&lt;/ul&gt; Пока вы не закроете окно, вы всё ещё можете нажимать кнопки Назад и Вперёд для возврата к уже посещённым страницам.</translation>
    </message>
    <message>
        <source>&amp;Clear Private Data</source>
        <translation>&amp;Очистить личные данные</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <comment>Clear Private Data</comment>
        <translation>Ctrl+Shift+Delete</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prefe&amp;rences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Reload Page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make Text &amp;Bigger</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make Text &amp;Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make Text &amp;Smaller</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Bookmarks Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Bookmarks Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not addded to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Очистить</translation>
    </message>
</context>
<context>
    <name>ClearPrivateData</name>
    <message>
        <source>Clear Private Data</source>
        <translation>Очистить личные данные</translation>
    </message>
    <message>
        <source>Clear the following items:</source>
        <translation>Очистить следующие элементы:</translation>
    </message>
    <message>
        <source>&amp;Browsing History</source>
        <translation>Журнал &amp;посещений</translation>
    </message>
    <message>
        <source>&amp;Download History</source>
        <translation>Журнал &amp;загрузок</translation>
    </message>
    <message>
        <source>&amp;Search History</source>
        <translation>Историю &amp;поиска</translation>
    </message>
    <message>
        <source>&amp;Cookies</source>
        <translation>&amp;Cookies</translation>
    </message>
    <message>
        <source>C&amp;ache</source>
        <translation>&amp;Кэш</translation>
    </message>
    <message>
        <source>Website &amp;Icons</source>
        <translation>З&amp;начки веб-сайтов</translation>
    </message>
    <message>
        <source>Clear &amp;Private Data</source>
        <translation>Очистить &amp;личные данные</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Отмена</translation>
    </message>
</context>
<context>
    <name>CookieExceptionsModel</name>
    <message>
        <source>Website</source>
        <translation>Веб-сайт</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Статус</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Разрешить</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Блокировать</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Разрешить на время сеанса</translation>
    </message>
</context>
<context>
    <name>CookieModel</name>
    <message>
        <source>Website</source>
        <translation>Веб-сайт</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Путь</translation>
    </message>
    <message>
        <source>Secure</source>
        <translation>Безопасность</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Истекает</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Содержимое</translation>
    </message>
</context>
<context>
    <name>CookiesDialog</name>
    <message>
        <source>Cookies</source>
        <translation>Cookies</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <source>Remove &amp;All Cookies</source>
        <translation>Удалить &amp;все cookies</translation>
    </message>
</context>
<context>
    <name>CookiesExceptionsDialog</name>
    <message>
        <source>Cookie Exceptions</source>
        <translation>Исключения cookies</translation>
    </message>
    <message>
        <source>New Exception</source>
        <translation>Новое исключение</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation>Домен</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Блокировать</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Разрешить на время сеанса</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Разрешить</translation>
    </message>
    <message>
        <source>Exceptions</source>
        <translation>Исключения</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Удалить &amp;все</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Загрузки</translation>
    </message>
    <message>
        <source>Clean up</source>
        <translation>Очистить</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 элементов</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Save File</source>
        <translation>Сохранить файл</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Загрузка отменена: %1</translation>
    </message>
    <message>
        <source>Error opening save file: %1</source>
        <translation>Ошибка при открытии сохранённого файла: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Ошибка при сохранении: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Ошибка сети: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>секунд</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation type="obsolete">минут</translation>
    </message>
    <message>
        <source>- %4 %5 remaining</source>
        <translation type="obsolete">- %4 %5 осталось</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation>%1 из  %2 (%3/сек) %4</translation>
    </message>
    <message>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 of %2 - Остановлено</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>байт</translation>
    </message>
    <message>
        <source>kB</source>
        <translation>кБ</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>МБ</translation>
    </message>
    <message>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <source>Ico</source>
        <translation>Ico</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Имя файла</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Повторить попытку</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Остановить</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message numerus="yes">
        <source>- %n minutes remaining</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>- %n seconds remaining</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message>
        <source>1 Download</source>
        <translation type="obsolete">1 загрузка</translation>
    </message>
    <message>
        <source>%1 Downloads</source>
        <translation type="obsolete">%1 загрузок</translation>
    </message>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Копировать</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Журнал</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Удалить &amp;все</translation>
    </message>
</context>
<context>
    <name>HistoryMenu</name>
    <message>
        <source>Show All History</source>
        <translation>Показать весь журнал</translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation>Очистить журнал</translation>
    </message>
</context>
<context>
    <name>HistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Название</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Адрес</translation>
    </message>
</context>
<context>
    <name>HistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Ранее сегодня</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation type="obsolete">%1 элементов</translation>
    </message>
    <message numerus="yes">
        <source>%n item(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>NetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Введите имя пользователя и пароль для &quot;%1&quot; на %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Connect to proxy &quot;%1&quot; using:&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Подключиться к прокси &quot;%1&quot;, используя:&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors?</source>
        <translation>Ошибки SSL:

%1

%2

Желаете ли вы игнорировать эти ошибки?</translation>
    </message>
    <message>
        <source>Do you want to accept all these certificates?</source>
        <translation>Вы желаете принять все эти сертификаты?</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Требуется аутентификация</translation>
    </message>
    <message>
        <source>DUMMY ICON</source>
        <translation>DUMMY ICON</translation>
    </message>
    <message>
        <source>INTRO TEXT DUMMY</source>
        <translation>INTRO TEXT DUMMY</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Имя пользователя:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Аутентификация прокси</translation>
    </message>
    <message>
        <source>ICON</source>
        <translation>ICON</translation>
    </message>
    <message>
        <source>Connect to proxy</source>
        <translation>Подключиться к прокси</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Имя пользователя:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The file is not an XBEL version 1.0 file.</source>
        <translation>Файл не является файлом XBEL версии 1.0.</translation>
    </message>
    <message>
        <source>Unknown title</source>
        <translation>Неизвестный заголовок</translation>
    </message>
</context>
<context>
    <name>SearchBanner</name>
    <message>
        <source>Form</source>
        <translation>Form</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation>TextLabel</translation>
    </message>
    <message>
        <source>&lt;</source>
        <translation>&lt;</translation>
    </message>
    <message>
        <source>&gt;</source>
        <translation>&gt;</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Готово</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Поиск</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <source>Home:</source>
        <translation>Домашняя страница:</translation>
    </message>
    <message>
        <source>Set to current page</source>
        <translation>Использовать текущую страницу</translation>
    </message>
    <message>
        <source>Remove history items:</source>
        <translation>Удалять элементы журнала:</translation>
    </message>
    <message>
        <source>After one day</source>
        <translation>Через день</translation>
    </message>
    <message>
        <source>After one week</source>
        <translation>Через неделю</translation>
    </message>
    <message>
        <source>After two weeks</source>
        <translation>Через две недели</translation>
    </message>
    <message>
        <source>After one month</source>
        <translation>Через месяц</translation>
    </message>
    <message>
        <source>After one year</source>
        <translation>Через год</translation>
    </message>
    <message>
        <source>Manually</source>
        <translation>Вручную</translation>
    </message>
    <message>
        <source>Save downloads to:</source>
        <translation type="obsolete">Сохранять загрузки в:</translation>
    </message>
    <message>
        <source>Open links from applications:</source>
        <translation>Открывать ссылки из приложений:</translation>
    </message>
    <message>
        <source>In a tab in the current window</source>
        <translation>Во вкладке в текущем окне</translation>
    </message>
    <message>
        <source>In a new window</source>
        <translation>В новом окне</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <source>Standard font:</source>
        <translation>Стандартный шрифт:</translation>
    </message>
    <message>
        <source>Times 16</source>
        <translation>Times 16</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Выбрать...</translation>
    </message>
    <message>
        <source>Fixed-width font:</source>
        <translation>Моноширинный шрифт:</translation>
    </message>
    <message>
        <source>Courier 13</source>
        <translation>Courier 13</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Конфиденциальность</translation>
    </message>
    <message>
        <source>Web Content</source>
        <translation>Веб-содержимое</translation>
    </message>
    <message>
        <source>Enable Plugins</source>
        <translation>Включить подключаемые модули</translation>
    </message>
    <message>
        <source>Enable Javascript</source>
        <translation>Включить JavaScript</translation>
    </message>
    <message>
        <source>Cookies</source>
        <translation>Cookies</translation>
    </message>
    <message>
        <source>Accept Cookies:</source>
        <translation>Принимать cookies:</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Всегда</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Никогда</translation>
    </message>
    <message>
        <source>Only from sites you navigate to</source>
        <translation>Только с посещённых сайтов</translation>
    </message>
    <message>
        <source>Exceptions...</source>
        <translation>Исключения...</translation>
    </message>
    <message>
        <source>Keep until:</source>
        <translation>Сохранять до:</translation>
    </message>
    <message>
        <source>They expire</source>
        <translation>Истечения срока</translation>
    </message>
    <message>
        <source>I exit the application</source>
        <translation>Выхода из приложения</translation>
    </message>
    <message>
        <source>At most 90 days</source>
        <translation>Максимум 90 дней</translation>
    </message>
    <message>
        <source>Cookies...</source>
        <translation>Cookies...</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Прокси</translation>
    </message>
    <message>
        <source>Enable proxy</source>
        <translation>Включить прокси</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <source>Socks5</source>
        <translation>Socks5</translation>
    </message>
    <message>
        <source>Http</source>
        <translation>Http</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Сервер:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <source>User Name:</source>
        <translation>Имя пользователя:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Дополнительно</translation>
    </message>
    <message>
        <source>Style Sheet:</source>
        <translation>Таблица стилей:</translation>
    </message>
    <message>
        <source>Sans-serif font:</source>
        <translation type="obsolete">Шрифт без засечек:</translation>
    </message>
    <message>
        <source>Serif font:</source>
        <translation type="obsolete">Шрифт с засечками:</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation type="obsolete">Размер:</translation>
    </message>
    <message>
        <source>Default font:</source>
        <translation type="obsolete">Шрифт по умолчанию:</translation>
    </message>
    <message>
        <source>Sans serif</source>
        <translation type="obsolete">Без засечек</translation>
    </message>
    <message>
        <source>Serif</source>
        <translation type="obsolete">С засечками</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Загрузки</translation>
    </message>
    <message>
        <source>Ask for a destination each time</source>
        <translation>Каждый раз спрашивать папку назначения</translation>
    </message>
    <message>
        <source>Use this destination:</source>
        <translation>Использовать эту папку назначения:</translation>
    </message>
    <message>
        <source>On startup:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restore windows and tabs from last time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>On application exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select tabs and windows as they are created</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Новая &amp;вкладка</translation>
    </message>
    <message>
        <source>Duplicate Tab</source>
        <translation>Копировать вкладку</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Закрыть вкладку</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Закрыть &amp;другие вкладки</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Обновить вкладку</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Обновить все вкладки</translation>
    </message>
    <message>
        <source>Show Tab Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Tab Bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>Новая &amp;вкладка</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Закрыть вкладку</translation>
    </message>
    <message>
        <source>Show Next Tab</source>
        <translation>Показать следующую вкладку</translation>
    </message>
    <message>
        <source>Show Previous Tab</source>
        <translation>Показать предыдущую вкладку</translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Недавно закрытые вкладки</translation>
    </message>
    <message>
        <source>(Untitled)</source>
        <translation>(Безымянный)</translation>
    </message>
    <message>
        <source>Do you really want to close this page?</source>
        <translation>Вы действительно хотите закрыть эту страницу?</translation>
    </message>
    <message>
        <source>You have modified this page and when closing it you would lose the modification.
Do you really want to close this page?
</source>
        <translation>Вы изменили эту страницу, и вы потеряете изменения при её закрытии.
Вы действительно хотите закрыть эту страницу?
</translation>
    </message>
</context>
<context>
    <name>ToolbarSearch</name>
    <message>
        <source>Google</source>
        <translation>Google</translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Нет последних слов для поиска</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Последние слова для поиска</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation>Очистить последние слова для поиска</translation>
    </message>
</context>
<context>
    <name>WebPage</name>
    <message>
        <source>Error loading page: %1</source>
        <translation>Ошибка при загрузке страницы: %1</translation>
    </message>
</context>
<context>
    <name>WebView</name>
    <message>
        <source>Open in New &amp;Window</source>
        <translation>Открыть в новом &amp;окне</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Открыть в новой &amp;вкладке</translation>
    </message>
    <message>
        <source>Save Lin&amp;k</source>
        <translation>Сохранить &amp;ссылку</translation>
    </message>
    <message>
        <source>&amp;Bookmark This Link</source>
        <translation>Добавить ссылку в &amp;закладки</translation>
    </message>
    <message>
        <source>&amp;Copy Link Location</source>
        <translation>&amp;Копировать адрес ссылки</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Window</source>
        <translation>Открыть изображение в новом &amp;окне</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Tab</source>
        <translation>Открыть изображение в новой &amp;вкладке</translation>
    </message>
    <message>
        <source>&amp;Save Image</source>
        <translation>&amp;Сохранить изображение</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>&amp;Копировать изображение</translation>
    </message>
    <message>
        <source>C&amp;opy Image Location</source>
        <translation>Копировать &amp;адрес изображения</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebViewSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Не найдено</translation>
    </message>
</context>
</TS>
